Document: gcl@EXT@-tk-doc
Title: GNU Common Lisp Tk Interface Documentation
Author: W. Schelter
Abstract: Documentation for Graphical Interface to GCL using TCL/Tk
Section: Programming

Format: PDF
Files: /usr/share/doc/gcl@EXT@/gcl-tk*.pdf.gz /usr/share/doc/gcl@EXT@-doc/gcl-tk*.pdf.gz

Format: HTML
Index: /usr/share/doc/gcl@EXT@/gcl-tk_html/index.html
Files: /usr/share/doc/gcl@EXT@/gcl-tk_html/*.html
